@@ -19,7 +19,7 @@ class FileChooser : public QDialog
     Q_OBJECT
 
  public:
-    FileChooser( QWidget *parent = 0, const char *name = 0);
+    FileChooser( QWidget *parent = 0, QString name="");
     Ui::FileChooser ui;
     QString fileName() const;
     QString filter,dir;
