@@ -11,7 +11,7 @@
 
 #include "structdialog.h"
 
-StructDialog::StructDialog(QWidget *parent, const char *name)
+StructDialog::StructDialog(QWidget *parent, QString name)
     : QDialog(parent)
 {
 setModal(true);
